<?php
/**
 * @file
 * Allows the site to send and receive user contacts to and from Text Marketer.
 */

/**
 * Implements hook_form().
 */
function textmarketer_contacts_admin_settings($form, &$form_state) {
  global $base_url;

  if (empty(variable_get('textmarketer_contacts_telephone_number', ''))) {
    drupal_set_message(t('Ensure you have created a telephone number field in
     the !account_settings_page. The field will be used for collecting user
     telephone numbers.', array(
       '!account_settings_page' => l(t('account settings page'),
      'admin/config/people/accounts/fields'),
     )), 'notice');
  }

  $account_fields = array();
  $account_fields = textmarketer_contacts_account_fields();
  $profile_fields = textmarketer_contacts_profile2_fields();
  $options_fields = array_merge($account_fields, $profile_fields);

  if (!empty($options_fields)) {
    $form = array();
    $form['settings_fieldset'] = array(
      '#type' => 'fieldset',
      '#title' => t('Text Marketer API Settings'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['settings_fieldset']['textmarketer_contacts_enable'] = array(
      '#type' => 'checkbox',
      '#default_value' => variable_get('textmarketer_contacts_enable', 0),
      '#title' => '<strong>' . t('Enable Text Marketer on this site') .
      '</strong>',
      '#description' => t('Must be enabled to start sending user mobile numbers
      from %this_site to Text Marketer.',
        array('%this_site' => $base_url)),
    );
    $form['settings_fieldset']['textmarketer_contacts_group_id'] = array(
      '#type' => 'textfield',
      '#default_value' => variable_get('textmarketer_contacts_group_id', ''),
      '#title' => '<strong>' . t('Text Marketer group ID') . '</strong>',
      '#description' => t('Enter the Text Marketer ID of the group to which
      you want to send numbers.'),
      '#size' => 14,
      '#maxlength' => 14,
      '#required' => TRUE,
    );
    $form['settings_fieldset']['textmarketer_contacts_group_name'] = array(
      '#type' => 'textfield',
      '#default_value' => variable_get('textmarketer_contacts_group_name', ''),
      '#title' => '<strong>' . t('Text Marketer group name') . '</strong>',
      '#description' => t('Enter the Text Marketer name of the group to which
       you want to send numbers. This is needed for updating mobile numbers.'),
      '#size' => 36,
      '#maxlength' => 128,
    );
    $form['settings_fieldset']['textmarketer_contacts_user_name'] = array(
      '#type' => 'textfield',
      '#default_value' => variable_get('textmarketer_contacts_user_name', ''),
      '#title' => '<strong>' . t('Text Marketer username') . '</strong>',
      '#description' => t('Enter the Text Marketer username.'),
      '#size' => 36,
      '#maxlength' => 128,
      '#required' => TRUE,
    );
    $form['settings_fieldset']['textmarketer_contacts_password'] = array(
      '#type' => 'textfield',
      '#default_value' => variable_get('textmarketer_contacts_password', ''),
      '#title' => '<strong>' . t('Text Marketer password') . '</strong>',
      '#description' => t('Enter the Text Marketer password.'),
      '#size' => 36,
      '#maxlength' => 128,
      '#required' => TRUE,
    );
    $form['settings_fieldset']['textmarketer_contacts_host'] = array(
      '#type' => 'textfield',
      '#default_value' => variable_get('textmarketer_contacts_host',
        'api.textmarketer.co.uk'),
      '#title' => '<strong>' . t('Text Marketer API Host') . '</strong>',
      '#description' => t('The Text Marketer API host. Do not include a slash
       in the URL.'),
      '#size' => 36,
      '#maxlength' => 128,
      '#required' => TRUE,
    );
    $form['settings_fieldset']['textmarketer_contacts_telephone_number']
      = array(
        '#type' => 'select',
        '#title' => '<strong>' . t('Text Marketer telephone field') .
        '</strong>',
        '#description' => t('Select the telephone number field that will be used
        by the site to send numbers to Text Marketer.'),
        '#options' => $options_fields,
        '#default_value' =>
        variable_get('textmarketer_contacts_telephone_number', ''),
        '#required' => TRUE,
      );
    $sms_subscribe_options = array('field_not_required' => 'Field not required')
      + $options_fields;
    $form['settings_fieldset']['textmarketer_contacts_subscribe_sms_list']
      = array(
        '#type' => 'select',
        '#title' => '<strong>' . t('Text Marketer subscribe to SMS field') .
        '</strong>',
        '#description' => t('If you want to send contact numbers only when a
        user ticks a checkbox, then select a checkbox field from the list.
        You must first create the field in the !account_settings_page', array(
          '!account_settings_page' => l(t('account settings page'),
          'admin/config/people/accounts/fields'),
        )),
        '#options' => $sms_subscribe_options,
        '#default_value' =>
        variable_get('textmarketer_contacts_subscribe_sms_list', ''),
      );

    return system_settings_form($form);
  }
  else {
    drupal_set_message(t('You do not have any user fields enabled. Create a
      telephone number field in the !account_settings_page before enabling this
      module. Remember to tick the checkbox display on the user registration
      form.'), array(
        '!account_settings_page' => l(t('account settings page'),
          'admin/config/people/accounts/fields'),
      ), 'warning'
    );
  }
}

/**
 * Construct an array of the user account fields.
 *
 * @return array
 *   Returns an array of user account fields.
 */
function textmarketer_contacts_account_fields() {
  $account_fields_info_instances = field_info_instances('user', 'user');

  if (!empty($account_fields_info_instances)) {
    foreach ($account_fields_info_instances as $field) {
      $account_fields[$field['field_name']] = $field['field_name'];
    }
  }
  return $account_fields;
}

/**
 * Construct an array of Profile2 fields.
 *
 * @return array
 *   An array containing the profile2 fields, if used.
 */
function textmarketer_contacts_profile2_fields() {
  if (module_exists('profile2')) {
    $profile2_field_info_instances = field_info_instances('profile2');

    if (!empty($profile2_field_info_instances)) {
      foreach ($profile2_field_info_instances as $profile_fields) {
        foreach ($profile_fields as $field_name => $field_data) {
          $profile_field[$field_name] = $field_name;
        }
      }
    }
    return $profile_field;
  }
  return array();
}
